import { ICryptoUtils } from "@snickerdoodlelabs/node-utils";
import { ConsentContractError, EVMAccountAddress, EVMContractAddress, IpfsCID, TokenUri, Signature, TokenId, RequestForData, BlockNumber, DomainName, BaseURI, HexString, HexString32, InvalidParametersError, ConsentToken, BigNumberString, BlockchainCommonErrors } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { IConsentContract } from "../interfaces/IConsentContract.js";
import { WrappedTransactionResponse, EConsentRoles, Tag, ContractOverrides } from "../interfaces/index.js";
export declare class ConsentContract extends ERC7529Contract<ConsentContractError> implements IConsentContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    protected cryptoUtils: ICryptoUtils;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress, cryptoUtils: ICryptoUtils);
    getContractAddress(): EVMContractAddress;
    optIn(tokenId: TokenId, agreementFlags: HexString32, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    encodeOptIn(tokenId: TokenId, agreementFlags: HexString32): HexString;
    restrictedOptIn(tokenId: TokenId, agreementFlags: HexString32, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    encodeRestrictedOptIn(tokenId: TokenId, signature: Signature, agreementFlags: HexString32): HexString;
    anonymousRestrictedOptIn(tokenId: TokenId, agreementFlags: HexString32, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    encodeAnonymousRestrictedOptIn(tokenId: TokenId, signature: Signature, agreementFlags: HexString32): HexString;
    optOut(tokenId: TokenId, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    encodeOptOut(tokenId: TokenId): HexString;
    agreementFlags(tokenId: TokenId): ResultAsync<HexString32, ConsentContractError | BlockchainCommonErrors>;
    getMaxCapacity(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    updateMaxCapacity(maxCapacity: number, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    updateAgreementFlags(tokenId: TokenId, newAgreementFlags: HexString32, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    encodeUpdateAgreementFlags(tokenId: TokenId, agreementFlags: HexString32): HexString;
    requestForData(ipfsCID: IpfsCID, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getConsentOwner(): ResultAsync<EVMAccountAddress, ConsentContractError | BlockchainCommonErrors>;
    getDefaultAdminRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError | BlockchainCommonErrors>;
    getSignerRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError | BlockchainCommonErrors>;
    getPauserRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError | BlockchainCommonErrors>;
    getRequesterRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError | BlockchainCommonErrors>;
    balanceOf(address: EVMAccountAddress): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    ownerOf(tokenId: TokenId): ResultAsync<EVMAccountAddress, ConsentContractError | BlockchainCommonErrors>;
    tokenURI(tokenId: TokenId): ResultAsync<TokenUri | null, ConsentContractError | BlockchainCommonErrors>;
    queryFilter(eventFilter: ethers.ContractEventName, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<(ethers.EventLog | ethers.Log)[], ConsentContractError | BlockchainCommonErrors>;
    getConsentToken(tokenId: TokenId): ResultAsync<ConsentToken, ConsentContractError | BlockchainCommonErrors>;
    addDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    removeDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getDomains(): ResultAsync<DomainName[], ConsentContractError | BlockchainCommonErrors>;
    getRequestForDataListByRequesterAddress(requesterAddress: EVMAccountAddress, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<RequestForData[], ConsentContractError | BlockchainCommonErrors>;
    getLatestTokenIdByOptInAddress(optInAddress: EVMAccountAddress): ResultAsync<TokenId | null, ConsentContractError | BlockchainCommonErrors>;
    disableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    enableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    baseURI(): ResultAsync<BaseURI, ConsentContractError | BlockchainCommonErrors>;
    setBaseURI(baseUri: BaseURI, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    hasRole(role: EConsentRoles, address: EVMAccountAddress): ResultAsync<boolean, ConsentContractError | BlockchainCommonErrors>;
    grantRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    revokeRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    renounceRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getQueryHorizon(): ResultAsync<BlockNumber, ConsentContractError | BlockchainCommonErrors>;
    setQueryHorizon(blockNumber: BlockNumber, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    estimateGasLimitForSetQueryHorizon(blockNumber: BlockNumber, overrides?: ContractOverrides): ResultAsync<BigNumberString, BlockchainCommonErrors | ConsentContractError>;
    totalSupply(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    openOptInDisabled(): ResultAsync<boolean, ConsentContractError | BlockchainCommonErrors>;
    getMaxTags(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    getNumberOfStakedTags(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    getTagArray(): ResultAsync<Tag[], ConsentContractError | BlockchainCommonErrors>;
    newGlobalTag(tag: string, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    newLocalTagUpstream(tag: string, newStakeAmount: BigNumberString, existingStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    newLocalTagDownstream(tag: string, existingStakeAmount: BigNumberString, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    replaceExpiredListing(tag: string, stakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    removeListing(tag: string, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    filters: {
        Transfer: (fromAddress: EVMAccountAddress | null, toAddress: EVMAccountAddress | null) => ethers.DeferredTopicFilter;
        RequestForData: (ownerAddress: EVMAccountAddress) => ethers.DeferredTopicFilter;
    };
    getSignature(values: (string | EVMAccountAddress | bigint | HexString | EVMContractAddress)[]): ResultAsync<Signature, InvalidParametersError>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): ConsentContractError;
}
//# sourceMappingURL=ConsentContract.d.ts.map